@@ -1,7 +1,7 @@
 /* addr_resolv.c
  * Routines for network object lookup
  *
- * $Id: addr_resolv.c 29099 2009-07-15 00:10:08Z gerald $
+ * $Id: addr_resolv.c 29703 2009-09-04 21:35:02Z gerald $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -505,8 +505,8 @@ add_serv_port_cb(guint32 port)
 static void parse_services_file(const char * path)
 {
   FILE *serv_p;
-  static int     size = 0;
-  static char   *buf = NULL;
+  char *buf = NULL;
+  int size = 0;
 
   /* services hash table initialization */
   serv_p = ws_fopen(path, "r");
@@ -517,7 +517,7 @@ static void parse_services_file(const char * path)
   while (fgetline(&buf, &size, serv_p) >= 0) {
     parse_service_line (buf);
   }
-
+  g_free(buf);
   fclose(serv_p);
 }
 
