@@ -1,6 +1,6 @@
 /* packet-rpc.h
  *
- * $Id: packet-rpc.h 26028 2008-08-14 23:51:52Z wmeier $
+ * $Id: packet-rpc.h 28128 2009-04-22 17:42:47Z gerald $
  *
  * (c) 1999 Uwe Girlich
  *
@@ -93,6 +93,10 @@
 #define AUTHDES_NAMEKIND_FULLNAME 0
 #define AUTHDES_NAMEKIND_NICKNAME 1
 
+#define RPC_STRING_EMPTY "<EMPTY>"
+#define RPC_STRING_DATA "<DATA>"
+#define RPC_STRING_TRUNCATED "<TRUNCATED>"
+
 extern const value_string rpc_authgss_svc[];
 typedef enum {
 	FLAVOR_UNKNOWN,		/* authentication flavor unknown */
